const fs = require('fs')

function pad(num, size = 2) {
  var s = num + '';
  while (s.length < size) s = '0' + s;
  return s;
}

module.exports = function organizeFile (filePath, file, outputDir) {
  //console.log(`📄 ${filePath}`)

  const stats = fs.statSync(filePath)

  // if that's a directory let's skip it.
  if (!stats.isDirectory()) {
    const birthtime = stats.birthtime

    let month = pad(birthtime.getMonth() + 1)
    let day = pad(birthtime.getDate())
    let year = birthtime.getFullYear()

    // check if we don't have the year folder created, to create it
    const yearDir = `${outputDir}/${year}`
    if (!fs.existsSync(yearDir)) {
      fs.mkdirSync(yearDir)
    }
    // same with month
    const monthDir = `${yearDir}/${month}`
    if (!fs.existsSync(monthDir)) {
      fs.mkdirSync(monthDir)
    }
    // same with day
    const dayDir = `${monthDir}/${year}_${month}_${day}`
    if (!fs.existsSync(dayDir)) {
      fs.mkdirSync(dayDir)
    }

    // move the file
    const moveStatus = dayDir
    let error
    try {
      fs.renameSync(filePath, `${dayDir}/${file}`)
      console.log('📄', filePath, `→ ${moveStatus} ✔️`);
    } catch (err) {
      console.log('❌', filePath, moveStatus, `ERROR: ${err}`);
      error = err
    }

    return {
      file,
      error
    }
  }
}
