const fs = require('fs')
const organizeFile = require('./organizeFile')

console.log('\n------------------------------------')
console.log('🗂  Welcome to KB\'s File Organizer 🗂')
console.log('------------------------------------\n')

console.log('Example: node script.js --from ~/Pictures/iPhoto\ Originals/2020/09 --to ~/Pictures/iPhoto\ Originals --incSub true')

const argv = require('yargs')
  .usage('Usage:')
  .options('from', {
    alias: 'sourceDirectory',
    default: './photos',
    describe: 'The directory containing photos/folders that need to be organized.'
  })
  .options('to', {
    alias: 'destinationDirectory',
    default: './output',
    describe: 'Root directory to store the organized photos.'
  })
  .options('incSub', {
    alias: 'includeSubdirectories',
    default: true,
    describe: 'Whether to organize subdirectories within directories.'
  })
  .help()
  .argv

function traverse (path, outputDir, includeDirectories) {
  fs.readdir(path, (err, files) => {
    if (err) {
      console.log(`Error getting directory information ${path}: ${JSON.stringify(err, null, 2)}`)
      return
    }

    // remove all hidden files
    files = files.filter(item => !(/(^|\/)\.[^\/\.]/g).test(item))

    // mention how many files total
    const totalFiles = files.length
    console.log(`📂 ${path} (${totalFiles})`)

    // create the output directory
    if (!fs.existsSync(outputDir)) {
      fs.mkdirSync(outputDir)
    }

    let i = 0
    // keep track of the files ones
    let errorFiles = []

    files.forEach(file => {
      // increase the current file count
      ++i

      const filePath = `${path}/${file}`

      const stats = fs.statSync(filePath)

      // if that's a directory let's recurse.
      if (stats.isDirectory()) {
        if (includeDirectories === true) {
          traverse(filePath, outputDir, includeDirectories)
        }
      } else {
        // organize that file and see if we got the file back
        const result = organizeFile(filePath, file, outputDir)
        if (result.error) {
          errorFiles.push(result.file)
        }
      }
    })

    console.log(`🗂  ${path} (${i}/${totalFiles}) ✔️\n`)
    if (errorFiles.length) {
      console.log(`⚠️  📂 ERRORS ${path} (${errorFiles.length}/${totalFiles}) ⚠️`)
      errorFiles.forEach((val, index) => {
        console.log(val)
      })
      console.log('\n')
    }
  })
}

traverse(argv.from, argv.to, argv.incSub === 'true')
